import { maintenance } from "../../../entity/unit/maintenance";
import { MaintenanceAssigned, MaintenanceViewModel } from "../../../viewmodel/admin/unit/maintenance.models";
import DamageReportFactory from "./damageReport";
import EquipmentFactory from "./equipment/equipment";
import VehicleFactory from "./vehicle/vehicle";
import WearableFactory from "./wearable/wearable";

export default abstract class MaintenanceFactory {
  /**
   * @description map record to maintenance
   * @param {maintenance} record
   * @returns {MaintenanceViewModel}
   */
  public static mapToSingle(record: maintenance): MaintenanceViewModel {
    let assigned: MaintenanceAssigned;
    if (record?.equipmentId) {
      assigned = {
        relatedId: record.equipmentId,
        assigned: "equipment",
        related: record.equipment ? EquipmentFactory.mapToSingle(record.equipment) : undefined,
      };
    } else if (record?.vehicleId) {
      assigned = {
        relatedId: record.vehicleId,
        assigned: "vehicle",
        related: record.vehicle ? VehicleFactory.mapToSingle(record.vehicle) : undefined,
      };
    } else if (record?.wearableId) {
      assigned = {
        relatedId: record.wearableId,
        assigned: "wearable",
        related: record.wearable ? WearableFactory.mapToSingle(record.wearable) : undefined,
      };
    } else {
      assigned = {
        relatedId: undefined,
        assigned: undefined,
        related: undefined,
      };
    }

    return {
      id: record.id,
      createdAt: record.createdAt,
      status: record.status,
      description: record.description,
      ...assigned,
    };
  }

  /**
   * @description map records to maintenance
   * @param {Array<maintenance>} records
   * @returns {Array<MaintenanceViewModel>}
   */
  public static mapToBase(records: Array<maintenance>): Array<MaintenanceViewModel> {
    return records.map((r) => this.mapToSingle(r));
  }
}
