import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createRepair,
  getAllRepairsByStatus,
  getAllRepairsForRelated,
  getRepairById,
  updateRepairById,
  updateRepairReportsById,
  updateRepairStatusById,
} from "../../../controller/admin/unit/repairController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllRepairsByStatus(req, res);
});

router.get(
  ["/vehicle/:relatedId", "/equipment/:relatedId", "/wearable/:relatedId"],
  async (req: Request, res: Response) => {
    if (req.path.startsWith("/vehicle")) {
      req.params.related = "vehicle";
    } else if (req.path.startsWith("/equipment")) {
      req.params.related = "equipment";
    } else {
      req.params.related = "wearable";
    }

    await getAllRepairsForRelated(req, res);
  }
);

router.get("/:id", async (req: Request, res: Response) => {
  await getRepairById(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("update", "unit", "repair"),
  async (req: Request, res: Response) => {
    await createRepair(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "unit", "repair"),
  async (req: Request, res: Response) => {
    await updateRepairById(req, res);
  }
);

router.patch(
  "/:id/reports",
  PermissionHelper.passCheckMiddleware("update", "unit", "repair"),
  async (req: Request, res: Response) => {
    await updateRepairReportsById(req, res);
  }
);

router.patch(
  "/:id/status",
  PermissionHelper.passCheckMiddleware("update", "unit", "repair"),
  async (req: Request, res: Response) => {
    await updateRepairStatusById(req, res);
  }
);

export default router;
